var jmaURI = "http://www.jma.go.jp/JMA_HP/jp/typh/";
var httpReq;
var typhNum;					// 地図を表示中の台風
var typhs = new Array();		// 台風の名前
var typhInfos = new Array();	// 台風の詳細情報（未実装）
var lastGetTime;				// 表示に使っているページの Last-Modified
var lastCheckTime;				// 最後にリロードを試みた時刻
var display;					// サイズ切り替え　未実装

// 定期リロード関連（30分毎にリロード）
var lastCheckTime;
var timerID;
var interval = 30*60*1000;

// widget初期化
function init() {
	if (window.widget) {
		widget.onshow = onShow;
	}

	// XMLHttpRequest
	httpReq = new XMLHttpRequest();
	httpReq.onreadystatechange = processReqChange;

	typhNum = 0;
	typhs.length = 0;
	lastCheckTime = 0;
	lastGetTime = "Thu, 01 Jan 1970 00:00:00 GMT";
	mapDisp(typhNum);
	display = "regular";

	// 初回の読み込み
	reload();

	// 定期リロード開始
	timerID = setInterval("reload()", interval);
}


// Dashboardレイヤー表示時
function onShow() {
	var now = (new Date).getTime();

	// スリープ対策
	// 前回リロード時からinterval-1秒以上経過していたらリロード
	if ((lastCheckTime != 0) &&
			(-1*1000 < (now - lastCheckTime - interval))) {
		reload();
	}
}


// 指定された番号の地図を表示
function mapDisp(num) {
	var i;
	for (i=0; i < 8; i++) {
		if (i == num) {
			document.getElementById("map"+i).style.display = "block";
			if (document.getElementById("typh"+i))
				document.getElementById("typh"+i).style.opacity = 1.0;
		} else {
			document.getElementById("map"+i).style.display = "none";
			if (document.getElementById("typh"+i))
				document.getElementById("typh"+i).style.opacity = 0.3;
		}
	}
	typhNum = num;
}

// 最新の情報で再描画
function reload() {
	var uri = jmaURI + "typh.all.html";	// 台風情報トップページ
	
	// デバッグ用
	document.getElementById("status").innerText = "";
	document.getElementById("header").innerText = "";
	document.getElementById("source").innerText = "";

	// Dashboardが用意するキャッシュを使いたくないので（？）
	// 強制的にリロードさせるための小細工（URIに「?ユニークな文字列」を付加）
	uri += "?" + new Date().getTime();

	alert ("Reload URI: " + uri );

	// HTTPリクエスト（非同期読み込み）
	// lastGetTimeよりも新しいコンテンツを要求する
	httpReq.open("GET", uri, true);
	if (0 < lastGetTime.length)
		httpReq.setRequestHeader("If-Modified-Since", lastGetTime);
	httpReq.send(null);
	
	lastCheckTime = (new Date).getTime();
}


// リクエスト状態（readyState）が変わったときに呼び出される
function processReqChange() {
	var buffer = new Array();
	var httpHeader = "";
	var htmlDoc = "";
	var i;

	// デバッグ用
	if (httpReq.readyState != 0) { // readyState 0 = uninitialized
//		alert("httpReq.readyState " + httpReq.readyState);
		document.getElementById("status").innerText = httpReq.status;
		document.getElementById("header").innerText = httpReq.getAllResponseHeaders();
	}

	if (httpReq.readyState == 4) { // readyState 4 = complete
		if (httpReq.status == 200) {						// 200:ダウンロード成功
			httpHeader = httpReq.getAllResponseHeaders();	// レスポンスヘッダ
			htmlDoc = httpReq.responseText;					// HTMLソース
	
			// 最終更新時刻を記録
			if (httpHeader.match(/Last-Modified: (.+)/i))
				lastGetTime = RegExp.$1;
			else
				lastGetTime = "";

			// 台風の名前を取得 (例) all, 0504, 0505, ...
			typhs.length = 0;
			buffer.length = 0;
			buffer = htmlDoc.match(/<option[^>]+>/g);
			if (0 < buffer.length) {
				for (i=0; i < buffer.length; i++) {
					if (buffer[i].match(/value=\"([^\"]+)\"/))
						typhs.push(RegExp.$1);
				}
			}

			document.getElementById("source").innerText = htmlDoc;
			reloadImg();
		}

		dispTyphs();
		mapDisp(typhNum);
	}
}


function reloadImg() {
	var imgURI;
	var i;

	for (i=0; i < typhs.length; i++) {
		imgURI = jmaURI + "images/typh." + typhs[i] + ".gif";
		// 強制的にリロードさせるための小細工
		imgURI += "?" + new Date().getTime();
		document.getElementById("map"+i).setAttribute("src", imgURI);
	}
}


// 台風セレクタの表示
function dispTyphs() {
	var typhsField = document.getElementById("typhs");
	var child;
	var typhName = "";
	var i;

	while (typhsField.hasChildNodes())
		typhsField.removeChild(typhsField.lastChild);

	for (i=0; i < typhs.length; i++) {
		if (typhs[i] == "all") {
			typhName = "ALL";
		} else {
			if (typhs[i].match(/[0-9][0-9]([0-9][0-9])/)) {
				typhName = RegExp.$1;
				typhName -= 0;	// 文字列から数値に変換
			}
		}

		child = document.createElement("div");
		child.innerText = typhName;
		child.id = "typh" + i;
		child.setAttribute("onclick", "mapDisp(" + i + ");");
		typhsField.appendChild(child);
	}
}


function openWWW() {
	var uri = jmaURI + "typh." + typhs[typhNum] + ".html";

	if (window.widget) {
		widget.openURL(uri);
	} else {
		window.location.href = uri;
	}
}

function mousemove() {
	document.getElementById("reload").style.display = "block";
	document.getElementById("jma").style.display = "block";
	document.getElementById("legend").style.display = "block";
}

function mouseexit() {
	document.getElementById("reload").style.display = "none";
	document.getElementById("jma").style.display = "none";
	document.getElementById("legend").style.display = "none";
}


function resize() {
	var i;

	switch (display) {
		case "regular":	// 標準からハーフサイズへ
			display = "half";
			document.getElementById("front").style.width = "314px";
			document.getElementById("front").style.height = "273px";
			document.getElementById("front").style.backgroundImage
				= "url('Images/half.png')";
			for (i=0; i < 8; i++) {
				document.getElementById("map"+i).style.width = "284px";
				document.getElementById("map"+i).style.height = "213px";
			}
			document.getElementById("legend").style.width = "270px";
			document.getElementById("legend").style.height = "38px";
			document.getElementById("legend").style.top = "204px";
			document.getElementById("legend").style.left = "22px";
			if (window.widget)
				window.resizeTo(314, 273);
			break;
		case "half":	// ハーフから標準サイズへ
			display = "regular";
			document.getElementById("front").style.width = "510px";
			document.getElementById("front").style.height = "420px";
			document.getElementById("front").style.backgroundImage
				= "url('Images/regular.png')";
			for (i=0; i < 8; i++) {
				document.getElementById("map"+i).style.width = "480px";
				document.getElementById("map"+i).style.height = "360px";
			}
			document.getElementById("legend").style.width = "460px";
			document.getElementById("legend").style.height = "64px";
			document.getElementById("legend").style.top = "320px";
			document.getElementById("legend").style.left = "25px";
			if (window.widget)
				window.resizeTo(510, 420);
			break;
		default:
			break;
	}
}
